﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using GestionRestaurante.SRR;
using System.Data.Services.Client;

namespace GestionRestaurante.PagesGestion
{
    /// <summary>
    /// Lógica de interacción para Usuarios.xaml
    /// </summary>
    public partial class Menus : Page
    {
        private RestauranteEntities context;
        private System.Windows.Data.CollectionViewSource platoViewSource;
        private Boolean leido;
        
        public Menus()
        {
            InitializeComponent();

            var scvUri = App.Current as App;
            Uri sUri = (Uri)scvUri.uriApp;
            context = new RestauranteEntities(sUri);       
        }

        private void Page_Loaded(object sender, RoutedEventArgs e)
        {

            this.lbTitulo.Content = this.Title;
            
            try
            {

                var qr = from m in context.Menu
                         select m;

                DataServiceCollection<GestionRestaurante.SRR.Menu> Lmenu = new
                    DataServiceCollection<GestionRestaurante.SRR.Menu>(context.Menu);
                this.menuDataGrid.DataContext = Lmenu;
                this.menuDataGrid.SelectedIndex = 0;

                platoViewSource = ((System.Windows.Data.CollectionViewSource)(this.FindResource("platoViewSource")));
                var platoTQuery = from p in context.Plato
                                 select p;

                platoViewSource.Source = platoTQuery.ToList();
              
                leido = true;
            }
            catch (Exception ex)
            {           
                MessageBox.Show(ex.ToString());
            }
        }

        private void btnSave_Click(object sender, RoutedEventArgs e)
        {
            GestionRestaurante.SRR.Menu myMenu = (GestionRestaurante.SRR.Menu)this.menuDataGrid.SelectedItem;
            context.SaveChanges();

            var qPlatos = from p in context.MenuPlato where p.idMenu == myMenu.idMenu select p;
            foreach (GestionRestaurante.SRR.Plato itRow in this.platoDataGrid.Items)
            {
                CheckBox chk = (CheckBox)this.platoDataGrid.Columns[4].GetCellContent(itRow);
                int tiene = qPlatos.Where(p => (p.idPlato == itRow.idPlato)).Count();

                if (chk.IsChecked == true && tiene==0)
                {
                    MenuPlato nuevo = new MenuPlato();
                    nuevo.idMenu = myMenu.idMenu;
                    nuevo.idPlato = itRow.idPlato;
                    context.AddToMenuPlato(nuevo);
                }
                else
                    if(chk.IsChecked == false && tiene==1)
                    {
                        MenuPlato mRef = qPlatos.Where(p => (p.idPlato == itRow.idPlato)).First();
                        context.DeleteObject(mRef);
                    }
                
            }
            
            try
            {
                // Save changes made to objects tracked by the context.
                context.SaveChanges();
                MessageBox.Show("Operación Correcta", "Guardar", MessageBoxButton.OK, MessageBoxImage.Information);
            }
            catch (DataServiceRequestException ex)
            {
                MessageBox.Show(ex.ToString());
            }
        }

        private void platoDataGrid_LayoutUpdated(object sender, EventArgs e)
        {

            if (leido == false) return;
            leido = false;
            if (this.menuDataGrid.CurrentItem != null)
            {
                GestionRestaurante.SRR.Menu myMenu = (GestionRestaurante.SRR.Menu)this.menuDataGrid.SelectedItem;
                            foreach (Plato itRow in this.platoDataGrid.Items)
                            {
                                int idm = myMenu.idMenu;
                                int idp = itRow.idPlato;

                                var query = (from c in context.MenuPlato
                                             where c.idPlato == idp
                                             select c).Where(p => (p.idMenu==idm));
                               
                                if (query.Count() == 1 )
                                {
                                  CheckBox chk = (CheckBox)this.platoDataGrid.Columns[4].GetCellContent(itRow);
                                    if (chk != null)
                                    {
                                        chk.IsChecked = true;
                                    }
                                }
                             }
            }

            
        }

        private void menuDataGrid_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            platoViewSource = ((System.Windows.Data.CollectionViewSource)(this.FindResource("platoViewSource")));
            var platoTQuery = from p in context.Plato
                              select p;

            List<Plato> myList = platoTQuery.ToList();
            platoViewSource.Source = myList;

            if (this.menuDataGrid.SelectedItem != null && this.menuDataGrid.SelectedItem.GetType() == typeof(GestionRestaurante.SRR.Menu))
                leido = true;
         
        }
  
    }
}
